package com.muyu.system.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.security.service.TokenService;
import com.muyu.common.system.domain.LoginUser;
import com.muyu.system.domain.SysNotice;
import com.muyu.system.domain.SysRoleDept;
import com.muyu.system.domain.UserNotice;
import com.muyu.system.domain.resp.UserNoticeRes;
import com.muyu.system.domain.vo.UserNoticeReq;
import com.muyu.system.mapper.SysNoticeMapper;
import com.muyu.system.mapper.SysUserMapper;
import com.muyu.system.service.SysNoticeService;
import jakarta.servlet.http.HttpServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 公告 服务层实现
 *
 * @author muyu
 */
@Service
public class SysNoticeServiceImpl extends ServiceImpl<SysNoticeMapper, SysNotice> implements SysNoticeService {
    @Autowired
    private SysNoticeMapper noticeMapper;
    @Autowired
    private SysUserMapper userMapper;
    @Autowired
    private TokenService tokenService;
    @Autowired
    private  HttpServletRequest request;

    /**
     * 查询公告信息
     *
     * @param noticeId 公告ID
     *
     * @return 公告信息
     */
    @Override
    public SysNotice selectNoticeById (Long noticeId) {
        return noticeMapper.selectNoticeById(noticeId);
    }

    /**
     * 查询公告列表
     *
     * @param notice 公告信息
     *
     * @return 公告集合
     */
    @Override
    public List<SysNotice> selectNoticeList (SysNotice notice) {
        return noticeMapper.selectNoticeList(notice);
    }

    /**
     * 新增公告
     *
     * @param notice 公告信息
     *
     * @return 结果
     */
    @Override
    public int insertNotice (SysNotice notice) {
        if (notice.getNoticeType().equals("1")){
            notice.setEndTime("");
        }
        //添加通知表
        int i = noticeMapper.insertNotice(notice);

        List<Integer> list=new ArrayList<>();

        //判断部门多选是否为空 ，如果不为空 查询总人数
        if (notice.getNoticeType().equals("1")&&notice.getCheckDeptList().length>0){
            list=userMapper.findUserByDept(notice.getCheckDeptList());
        }
        //判断人员多选是否为空 ，如果不为空
        if (notice.getNoticeType().equals("1")&&notice.getCheckUserList().length>0){
            for (Integer userId : notice.getCheckUserList()) {
                list.add(userId);
            }
        }
        //如果通知类型为公告 通知所有人
        if (notice.getNoticeType().equals("2")){
            list=userMapper.findAllUser();
        }
        //添加信息中间表
        noticeMapper.addUserNotice(list,notice.getNoticeId(),notice.getEndTime());

        return i;
    }

    /**
     * 修改公告
     *
     * @param notice 公告信息
     *
     * @return 结果
     */
    @Override
    public int updateNotice (SysNotice notice) {
        return noticeMapper.updateNotice(notice);
    }

    /**
     * 删除公告对象
     *
     * @param noticeId 公告ID
     *
     * @return 结果
     */
    @Override
    public int deleteNoticeById (Long noticeId) {
        return noticeMapper.deleteNoticeById(noticeId);
    }

    /**
     * 批量删除公告信息
     *
     * @param noticeIds 需要删除的公告ID
     *
     * @return 结果
     */
    @Override
    public int deleteNoticeByIds (Long[] noticeIds) {
        return noticeMapper.deleteNoticeByIds(noticeIds);
    }

    @Override
    public List<UserNoticeRes> findNoticeByUserId(UserNoticeReq notice) {
        LoginUser loginUser = tokenService.getLoginUser(request);
        notice.setUserId(loginUser.getUserid());

        return noticeMapper.findNoticeByUserId(notice);
    }



    @Override
    public void updNoticeStatus(Integer id) {
         noticeMapper.updNoticeStatus(id);
    }

    @Override
    public String findNoticeSumByUserId(String noticeId) {
        return noticeMapper.findNoticeSumByUserId(noticeId);
    }

    @Override
    public String findNoticeCountByUserId(String noticeId) {
        return noticeMapper.findNoticeCountByUserId(noticeId);
    }
}
